@@ -290,7 +290,9 @@ class SPKProfileInput(BaseModel):
         title: Title of HTML representation.
         data: List of data.
         missing_diagrams: Settings related with the missing data section and the visualizations it can include.
+        vars: Vars to provide another settings.
         correlations: Settings regarding correlation metrics and thresholds.
+        sort: Default sorting.
         progress_bar: If True will display a progress bar.
         minimal: Minimal mode is a default configuration with minimal computation.
         explorative: Explorative mode.
@@ -304,7 +306,9 @@ class SPKProfileInput(BaseModel):
     html: Dict = {}
     missing_diagrams: Dict = {}
     correlations: Dict = {}
+    vars: Dict = {}
     data: List[Dict[str, Any]]
+    sort: str = "ascending"
     progress_bar: bool = False
     minimal: bool = False
     explorative: bool = False
@@ -316,14 +320,8 @@ class SPKProfileInput(BaseModel):
 class SPKProfileDTO(BaseModel):
     """
     Pydantic model of Profile HTML representation
-
-    Attributes:
-
-        data: Profile html representation.
     """
 
-    data: str
-
 
 class SPKLearnsetInput(BaseModel):
     """
@@ -629,10 +627,18 @@ class SPKTaxonomyDataDTO(SPKTaxonomyDataInput, MongoId):
     """
 
 
-class SPKEmailConverterResponse(BaseModel):
-    content_attachments: List[SDUAttachment]
-    txt_content: SDUText
-    msg: SDUEmail
+class SPKConversionInput(BaseModel):
+    """
+    Model that contains inference data along with filenames to use for XLSX conversion.
+
+    Attributes:
+
+        filenames: list of filenames that files should be saved as
+        inference: inference data
+    """
+
+    filenames: List[str]
+    inference: List[Dict[str, Any]]
 
 
 class SPKHTMLConverterResponse(BaseModel):
@@ -649,6 +655,13 @@ class SPKHTMLConverterResponse(BaseModel):
     txt_content: SDUText
 
 
+class SPKEmailConverterResponse(BaseModel):
+    content_attachments: List[SDUAttachment]
+    txt_content: SDUText
+    msg: SDUEmail
+    content_unzipped_files: Optional[List[SPKHTMLConverterResponse]]
+
+
 class FieldName(str, Enum):
     """Matching pydantic models with fields in the db.
     Attributes:
@@ -662,3 +675,12 @@ class FieldName(str, Enum):
     LearnsetDataInput = "learnset"
     ModelDataInput = "model"
     TaxonomyDataInput = "taxonomy"
+
+def change_value(mydict: dict ):
+    mydict["hello"] = 5
+
+if __name__ == "__main__":
+    a = {"hello": 3}
+    print(a)
+    change_value(a)
+    print(a)
